function []=MotionDetection_metodo1(nome_cartella,estensione_file, esposizione, movimento)

% MotionDetection_metodo1(nome_cartella, esposizione, movimento)
% Rileva il movimento da due immagini a lunga esposizione
%
% le immagini statiche e di movimento devono essere nella stessa cartella
% di nome /nome_cartella/esposizione
% Le 2 immagini di movimento devono chiamarsi:
%                   - esposizione_movimento_1.estensione_file
%                   - esposizione_movimento_2.estensione_file
% Le 2 immagini statiche utilizzate per calcolare la soglia del rumore devono chiamarsi:
%                   - esposizione_noise_1.estensione_file
%                   - esposizione_noise_2.estensione_file
%   Esempio: per analizzare due immagini in formato tif di 5 secondi di esposizione, rappresentanti 
%            il primo movimento da analizzare in un giardino,esse dovranno essere
%            poste un una cartella chiamata '5' posta in una cartella
%            chiamata ad esempio 'Giardino'.
%            nella cartella '5' dovranno essere presenti le due immagini di
%            movimento chiamate 5_1_1.tif e 5_1_2.tif, e le due immagini
%            statiche per calcolare la soglia del rumore chiamate
%            5_noise_1.tif e 5_noise_2.tif
%
% input:
%   - nome_cartella: directory nella quale sono contenuti le immagini a
%                    lunga esposizione
%   - estensione_file: estensione dei file di immagine
%   - esposizione: tempo di esposizione in secondi delle immagini da
%                  analizzare
%   - movimento: intero che indica il movimento utilizzato
%
% Il metodo utilizzato prevede la differenza tra le immagini di movimento,
% l'applicazione di un filtro mediano a tale differenza e successivamente
% il calcolo del valore assoluto.
% Per il calcolo della soglia di rumore viene eseguita la differenza per ogni canale RGB
% di due immagini statiche della scena da osservare, viene applicato un filtro
% mediano e successivamente il valore assoluto. Viene presa come soglia di rumore 
% il valore massimo che si ottiene per ogni canale RGB.
% 

%dimensione del filtro mediano, impostato in modo che sia grande circa quanto la
%testa di una persona nella scena
dim_testa = [15 15];

%% LETTURA IMMAGINI

    %Leggo le due immagini statiche per rilevare la soglia di rumore
    static1_big=im2double((imread(strcat(nome_cartella,'/',esposizione,'/',esposizione,'_noise_1.',estensione_file))));
    static2_big=im2double((imread(strcat(nome_cartella,'/',esposizione,'/',esposizione,'_noise_2.',estensione_file))));

    %Leggo le due immagini da confrontare
    im1_big=im2double((imread(strcat([nome_cartella,'/',esposizione,'/',esposizione,'_',movimento,'_1.',estensione_file]))));
    im2_big=im2double((imread(strcat([nome_cartella,'/',esposizione,'/',esposizione,'_',movimento,'_2.',estensione_file]))));


%% IMAGE RESIZE  

    static1=imresize(static1_big,[NaN 800]);
    static2=imresize(static2_big,[NaN 800]);

    im1=imresize(im1_big,[NaN 800]);
    im2=imresize(im2_big,[NaN 800]);
        
    %prelevo le dimensioni dell'immagine
    dimensione_immagine = size(im1);
    width = dimensione_immagine(2);
    height = dimensione_immagine(1);
    
%% CALCOLO DELLE DIFFERENZE

    differenze = zeros(height,width,3);
    diff_noise = zeros(height,width,3);
    
    for i=1:height 
        for j=1:width 
            for canale=1:3
            %differenza nell'immagine
            differenze(i,j,canale) = im1(i,j,canale) - im2(i,j,canale);
            
            %differenze dovute al rumore (per il calcolo automatico della
            %soglia)
            diff_noise(i,j,canale) = static1(i,j,canale) - static2(i,j,canale);

            end
        end
    end
    
%% APPLICAZIONE DEL FILTRO MEDIANO
    
    %applico il filtro mediano alle differenze tra le immagini 
    differenze_mediana(:,:,1) = medfilt2(differenze(:,:,1),dim_testa);
    differenze_mediana(:,:,2) = medfilt2(differenze(:,:,2),dim_testa);
    differenze_mediana(:,:,3) = medfilt2(differenze(:,:,3),dim_testa);
    
    %applico il filtro mediano alle differenze tra le immagini statiche
    diff_noise_mediana(:,:,1) = medfilt2(diff_noise(:,:,1),dim_testa);
    diff_noise_mediana(:,:,2) = medfilt2(diff_noise(:,:,2),dim_testa);
    diff_noise_mediana(:,:,3) = medfilt2(diff_noise(:,:,3),dim_testa);

%% APPLICAZIONE VALORE ASSOLUTO

    %applico il valore assoluto alle differenze
    differenze_mediana_assolute = abs(differenze_mediana);
    diff_noise_mediana_assolute = abs(diff_noise_mediana);

%% RICERCA DELLA SOGLIA

    %trovo il valore massimo del rumore su ogni canale
    max_diff_rumore_1 = max(max(diff_noise_mediana_assolute(:,:,1)));
    max_diff_rumore_2 = max(max(diff_noise_mediana_assolute(:,:,2)));
    max_diff_rumore_3 = max(max(diff_noise_mediana_assolute(:,:,3)));
    
    %imposto una soglia
    soglia = [max_diff_rumore_1  max_diff_rumore_2   max_diff_rumore_3];

%% APPLICAZIONE DELLA SOGLIA

    %creo una immagine RGB vuota nera
    motion = zeros(height, width); 
        
    %soglio con il rumore
    for i=1:height 
        for j=1:width 
            for canale=1:3

            if(differenze_mediana_assolute(i,j,canale) > soglia(canale))
                motion(i,j) = 1;
            end
            
            end
        end
    end

%% RICERCA DEL CONTORNO

    thresh=0.23;
    sigma=1.1;
    motionborder = edge(motion,'canny',thresh,sigma);
    
    %Evidenzio il movimento con un contorno rosso
    image_and_motion = im1;
     for i=1:height 
        for j=1:width 
            if(motionborder(i,j) == 1)
                image_and_motion(i,j,1) = 255;
                image_and_motion(i,j,2) = 0;
                image_and_motion(i,j,3) = 0;
            end
        end
     end
         
%% SALVATAGGIO DELLE IMMAGINI
    
% vengono salvate 4 immagini: 
%   valore assoluto delle differenze
    imwrite (rgb2gray(abs(differenze)), strcat(nome_cartella,'/',esposizione,'/result_greyscale_metodo1.jpeg'), 'Quality', 100);  
%   valore assoluto delle differenze dopo l'applicazione del filtro mediano
    imwrite (rgb2gray(differenze_mediana_assolute), strcat(nome_cartella,'/',esposizione,'/result_greyscale_median_metodo1.jpeg'), 'Quality', 100);
%   Movimento rilevato
    imwrite (motion, strcat(nome_cartella,'/',esposizione,'/binary_result_metodo1.jpeg'), 'Quality', 100);
%   Disegno sull'immagine originale del movimento rilevato
    imwrite (image_and_motion, strcat(nome_cartella,'/',esposizione,'/canny_result_metodo1.jpeg'), 'Quality', 100);
    